@@ -1,14 +1,14 @@
-version = '0.8.20.0.131'
+version = '0.8.20.0.203'
 
-date = '2020-05-06'
+date = '2021-01-01'
 
 dpi = 128
 # coding:utf-8
 
-from geopytool.ImportDependence import *
+from ImportDependence import *
 
 
-# from geopytool.TableViewer import TableViewer
+# from TableViewer import TableViewer
 from cycler import cycler
 
 # Create cycler object. Use any styling from above you please
