@@ -21,6 +21,9 @@ import subprocess
 import webbrowser
 import sys
 import sklearn as sk
+
+from sklearn.neural_network import MLPClassifier
+
 #import vispy.app, vispy.visuals, vispy.scene, vispy.plot, vispy.io, vispy.color
 #import sklearn_pandas as skpd
 
@@ -84,7 +87,7 @@ from matplotlib.backends.backend_qt5agg import FigureCanvasQTAgg as FigureCanvas
 from matplotlib.backends.backend_qt5 import NavigationToolbar2QT as NavigationToolbar
 from matplotlib import ft2font
 from bs4 import BeautifulSoup
-#from geopytool.TableViewer import TableViewer
+#from TableViewer import TableViewer
 
 
 
